<?php
/**
 * SPDX-FileCopyrightText: 2024 Sascha Nitsch (grumpydeveloper) https://contentnation.net/@grumpydevelop
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * @author Sascha Nitsch (grumpydeveloper)
 **/

 namespace Federator\Connector;

 /**
  * Connector to ContentNation.net
  */
class ContentNation implements Connector
{
    /**
     * service-URL
     *
     * @var string $service
     */
    private $service;

    /**
     * constructor
     *
     * @param array<string, mixed> $config
     */
    public function __construct($config)
    {
        $this->service = $config['service-uri'];
    }

    /**
     * get remote user by given session
     *
     * @param string $_session session id
     * @param string $_user user or profile name
     * @return \Federator\Data\User | false
     */
    public function getRemoteUserBySession(string $_session, string $_user)
    {
        // validate $_session and $user
        if (preg_match("/^[a-z0-9]{16}$/", $_session) != 1) {
            return false;
        }
        if (preg_match("/^[a-zA-Z0-9_\-]+$/", $_user) != 1) {
            return false;
        }
        $remoteURL = $this->service . '/api/users/permissions?profile=' . urlencode($_user);
        $headers = ['Cookie: session=' . $_session, 'Accept: application/json'];
        [$response, $info] = \Federator\Main::getFromRemote($remoteURL, $headers);

        if ($info['http_code'] != 200) {
            return false;
        }
        $r = json_decode($response, true);
        if ($r === false || !is_array($r) ||  !array_key_exists($_user, $r)) {
            return false;
        }
        $user = new \Federator\Data\User();
        $user->externalid = $_user;
        $user->permissions = [];
        $user->session = $_session;
        foreach ($r[$_user] as $p) {
            $user->permissions[] = $p;
        }
        return $user;
    }
}

namespace Federator;

/**
 * Function to initialize plugin
 *
 * @param  \Federator\Main $main main instance
 * @return void
 */
function contentnation_load($main)
{
    $cn = new Connector\ContentNation($main->getConfig()['contentnation']);
    $main->setConnector($cn);
}
